@@ -1,7 +1,8 @@
+from StringIO import StringIO
 import requests, msgpack, pickle, time, calendar
 
 DEFAULT_HOST = "localhost"
-DEFAULT_PORT = 8080
+DEFAULT_PORT = 38080
 DEFAULT_DB   = "oleg"
 
 class OlegDB(object):
@@ -15,6 +16,11 @@ class OlegDB(object):
                 host=self.host, port=self.port, db_name=self.db_name, key=key)
         return connect_str
 
+    def _build_prefix_str(self, prefix):
+        connect_str = "http://{host}:{port}/{db_name}/{prefix}/_match".format(
+                host=self.host, port=self.port, db_name=self.db_name, prefix=prefix)
+        return connect_str
+
     def _pack_item(self, value):
         new_value = None
         try:
@@ -75,11 +81,30 @@ class OlegDB(object):
         return int(resp.headers['expires'])
 
     def get_many(self, keys):
+        unjar_str = '\n'.join([str(x) for x in keys])
+        connect_str = self._build_host_str('_bulk_unjar')
+        resp = requests.post(connect_str, data=unjar_str, stream=True)
+        if resp.status_code == 404:
+            return {}
+
+        key_iter = 0
+        reader = StringIO(resp.text.encode('utf-8'))
         many = {}
-        for key in keys:
-            returned = self.get(key, version)
-            if returned:
-                many[key] = returned
+        while True:
+            size = reader.read(8)
+            if size == '':
+                break
+            size = int(size)
+
+            value = reader.read(size)
+            if value == '':
+                break
+
+            key = keys[key_iter]
+            many[key] = value
+            key_iter = key_iter + 1
+        reader.close()
+
         return many
 
     def has_key(self, key):
@@ -97,3 +122,14 @@ class OlegDB(object):
         for key in keys:
             self.delete(key, value, timeout)
 
+    def get_by_prefix(self, prefix):
+        to_return = []
+        connect_str = self._build_prefix_str(prefix)
+        resp = requests.get(connect_str, stream=True)
+        if resp.status_code == 404:
+            return to_return
+
+        for line in resp.text.split("\n"):
+            to_return.append(line)
+
+        return to_return
